@@ -3,7 +3,7 @@
 . `dirname $0`/sdbs.inc
 
 for module in \
-    Mojolicious \
+    Mojolicious@5.0 \
 ; do
     perlmodule $module
 done
